@@ -86,7 +86,7 @@ def get_frame_handler(frame_type: int) -> str:
     if frame_type in FRAME_TYPES:
         return f"frames.{FRAME_TYPES[frame_type]}"
 
-    raise UnknownFrameError(f"unknown frame type {frame_type}")
+    raise UnknownFrameError(f"Unknown frame type ({frame_type})")
 
 
 @dataclass
@@ -122,10 +122,6 @@ class Frame(ABC, FrameDataClass):
         """Return frame length."""
         return self.length
 
-    def is_type(self, *args) -> bool:
-        """Check if frame is instance of type."""
-        return any(self.frame_type == x for x in args)
-
     @abstractmethod
     def create_message(self, data: DeviceDataType) -> MessageType:
         """Create frame message."""
