@@ -6,7 +6,7 @@ from typing import Final, Optional, Tuple
 
 from pyplumio import util
 from pyplumio.const import BROADCAST_ADDRESS, ECONET_ADDRESS
-from pyplumio.exceptions import ChecksumError
+from pyplumio.exceptions import ChecksumError, ReadError
 from pyplumio.frames import FRAME_START, HEADER_SIZE, Frame, get_frame_handler
 from pyplumio.helpers.factory import factory
 from pyplumio.helpers.timeout import timeout
@@ -14,6 +14,9 @@ from pyplumio.helpers.timeout import timeout
 READER_TIMEOUT: Final = 10
 WRITER_TIMEOUT: Final = 10
 
+MIN_FRAME_LENGTH: Final = 10
+MAX_FRAME_LENGTH: Final = 1000
+
 
 class FrameWriter:
     """Represents frame writer."""
@@ -50,12 +53,14 @@ class FrameReader:
     async def _read_header(self) -> Tuple[bytes, int, int, int, int, int]:
         """Locate and read frame header."""
         while True:
-            buffer = await self._reader.read(1)
-            if buffer and buffer[0] == FRAME_START:
+            header = await self._reader.read(1)
+            if header and header[0] == FRAME_START:
                 break
 
-        buffer += await self._reader.read(HEADER_SIZE - 1)
-        header = buffer[0:HEADER_SIZE]
+        header += await self._reader.read(HEADER_SIZE - 1)
+        if len(header) < HEADER_SIZE:
+            raise ReadError(f"Header can't be less than {HEADER_SIZE} bytes")
+
         [
             _,
             length,
@@ -64,15 +69,14 @@ class FrameReader:
             sender_type,
             econet_version,
         ] = util.unpack_header(header)
-        buffer += await self._reader.read(length - HEADER_SIZE)
 
-        return buffer, length, recipient, sender, sender_type, econet_version
+        return header, length, recipient, sender, sender_type, econet_version
 
     @timeout(READER_TIMEOUT)
     async def read(self) -> Optional[Frame]:
         """Read the frame and return corresponding handler object."""
         (
-            frame,
+            header,
             length,
             recipient,
             sender,
@@ -82,10 +86,18 @@ class FrameReader:
 
         if recipient in (ECONET_ADDRESS, BROADCAST_ADDRESS):
             # Destination address is econet or broadcast.
-            payload = frame[HEADER_SIZE:length]
+            payload = await self._reader.read(length - HEADER_SIZE)
+            payload_size = len(payload)
 
-            if payload[-2] != util.crc(frame[:-2]):
-                raise ChecksumError("incorrect frame checksum")
+            if (
+                length > MAX_FRAME_LENGTH
+                or length < MIN_FRAME_LENGTH
+                or (payload_size + HEADER_SIZE) != length
+            ):
+                raise ReadError(f"Unexpected frame size ({payload_size})")
+
+            if payload[-2] != util.crc(header + payload[:-2]):
+                raise ChecksumError(f"Incorrect frame checksum ({payload[-2]})")
 
             return factory(
                 get_frame_handler(frame_type=payload[0]),
